/* This file is part of Mailfromd.             -*- c -*-
   Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011 Sergey Poznyakoff

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>. */

#include "syslog.h"
#include "mflib/syslog.h"

struct syslog_transtab
{
	int mfc;
	int sys;
};

static struct syslog_transtab syslog_prio[] = {
	{ _MF_LOG_EMERG,      LOG_EMERG     },
	{ _MF_LOG_ALERT,      LOG_ALERT     },
	{ _MF_LOG_CRIT,       LOG_CRIT      },
	{ _MF_LOG_ERR,        LOG_ERR       },
	{ _MF_LOG_WARNING,    LOG_WARNING   },
	{ _MF_LOG_NOTICE,     LOG_NOTICE    },
	{ _MF_LOG_INFO,       LOG_INFO      },
	{ _MF_LOG_DEBUG,      LOG_DEBUG     },
};

static struct syslog_transtab syslog_fac[] = {
	{ _MF_LOG_KERN,       LOG_KERN      },
	{ _MF_LOG_USER,       LOG_USER      },
	{ _MF_LOG_MAIL,       LOG_MAIL      },
	{ _MF_LOG_DAEMON,     LOG_DAEMON    },
	{ _MF_LOG_AUTH,       LOG_AUTH      },
	{ _MF_LOG_SYSLOG,     LOG_SYSLOG    },
	{ _MF_LOG_LPR,        LOG_LPR       },
	{ _MF_LOG_NEWS,       LOG_NEWS      },
	{ _MF_LOG_UUCP,       LOG_UUCP      },
	{ _MF_LOG_CRON,       LOG_CRON      },
	{ _MF_LOG_AUTHPRIV,   LOG_AUTHPRIV  },
	{ _MF_LOG_FTP,        LOG_FTP       },
	{ _MF_LOG_LOCAL0,     LOG_LOCAL0    },
	{ _MF_LOG_LOCAL1,     LOG_LOCAL1    },
	{ _MF_LOG_LOCAL2,     LOG_LOCAL2    },
	{ _MF_LOG_LOCAL3,     LOG_LOCAL3    },
	{ _MF_LOG_LOCAL4,     LOG_LOCAL4    },
	{ _MF_LOG_LOCAL5,     LOG_LOCAL5    },
	{ _MF_LOG_LOCAL6,     LOG_LOCAL6    },
	{ _MF_LOG_LOCAL7,     LOG_LOCAL7    }
};

MF_DEFUN(syslog, VOID, NUMBER priority, STRING text)
{
	int i;
	int prio = 0;
	int f = 0;

	prio = priority & _MF_LOG_PRIMASK;
	for (i = 0; i < sizeof(syslog_fac)/sizeof(syslog_fac[0]);
	     i++) {
		if (syslog_prio[i].mfc == prio) {
			prio = syslog_prio[i].sys;
			break;
		}
	}
	priority &= ~_MF_LOG_PRIMASK;
	
	for (i = 0; i < sizeof(syslog_fac)/sizeof(syslog_fac[0]);
	     i++) {
		if (syslog_fac[i].mfc == priority) {
			f = syslog_fac[i].sys;
			break;
		}
	}
	if (f == 0)
		f = priority;
	
	logger_text(prio | f, text);
}
END

MF_INIT
